<?php

namespace Drupal\dblog_ban\Services;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\CsrfAccessCheck;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\HttpFoundation\ParameterBag;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Route;

/**
 * Allows access to routes to be controlled by a '_csrf_token' parameter.
 *
 * To use this check, add a "token" GET parameter to URLs of which the value is
 * a token generated by \Drupal::csrfToken()->get() using the same value as the
 * "_csrf_token" parameter in the route.
 *
 * @todo Remove this class when https://www.drupal.org/node/2670798 is merged.
 * @internal
 */
class CsrfAjaxAccessCheck extends CsrfAccessCheck {

  /**
   * {@inheritdoc}
   */
  public function access(Route $route, Request $request, RouteMatchInterface $route_match) {
    $parameters = $route_match->getRawParameters();
    if ($parameters instanceof ParameterBag) {
      $parameters = $parameters->all();
    }
    $path = RouteProcessorCsrfAjax::preparePath($route, $parameters);

    if ($this->csrfToken->validate($request->query->get('token', ''), $path)) {
      $result = AccessResult::allowed();
    }
    else {
      $result = AccessResult::forbidden($request->query->has('token') ? "'dblog_ban_csrf_ajax_token' URL query argument is invalid." : "'dblog_ban_csrf_ajax_token' URL query argument is missing.");
    }
    // Not cacheable because the CSRF token is highly dynamic.
    return $result->setCacheMaxAge(0);
  }

}
